..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

===============
 Invenio-Admin
===============

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-admin.svg
        :target: https://github.com/inveniosoftware/invenio-admin/blob/master/LICENSE

.. image:: https://github.com/inveniosoftware/invenio-admin/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-admin/actions

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-admin.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-admin

.. image:: https://img.shields.io/pypi/v/invenio-admin.svg
        :target: https://pypi.org/pypi/invenio-admin


Invenio-Admin allows for easy administration of any Invenio installation,
simple data curation and execution of actions.

* Provides default administration panel using Flask-Admin.

* Easily extendible from other Invenio modules using entry points.

Further documentation at: https://invenio-admin.readthedocs.io/
